==> racer-0.1.1.tgz: package/lib/Serializer.js <==
var DEFAULT_TIMEOUT, Serializer, transaction;
transaction = require('./transaction');
DEFAULT_TIMEOUT = 1000;
module.exports = Serializer = function(_arg) {
  var init, onTimeout, self, timeout;
  this.withEach = _arg.withEach, onTimeout = _arg.onTimeout, timeout = _arg.timeout, init = _arg.init;
  self = this;
  if (onTimeout) {
    if (timeout === void 0) {
      timeout = DEFAULT_TIMEOUT;
    }
    self._setWaiter = function() {
      if (this._waiter) {
        return;
      }
      return this._waiter = setTimeout(function() {
        onTimeout();
        return self._clearWaiter();
      }, timeout);
    };
    self._clearWaiter = function() {
      if (this._waiter) {
        clearTimeout(this._waiter);
        return this._waiter = null;
      }
    };
  }
  self._pending = {};
  self._index = init != null ? init : 1;
};
Serializer.prototype = {
  _setWaiter: function() {},
  _clearWaiter: function() {},
  add: function(txn, txnIndex) {
    var index, pending;
    index = this._index;
    if (txnIndex > index) {
      this._pending[txnIndex] = txn;
      this._setWaiter();
      return true;
    }
    if (txnIndex < index) {
      return false;
    }
    this.withEach(txn, index);
    this._clearWaiter();
    index++;
    pending = this._pending;
    while (txn = pending[index]) {
      this.withEach(txn, index);
      delete pending[index++];
    }
    this._index = index;
    return true;
  },
  setIndex: function(_index) {
    this._index = _index;
  },
  clearPending: function() {
    var i, index, pending, _results;
    index = this._index;
    pending = this._pending;
    _results = [];
    for (i in pending) {
      _results.push(i < index ? delete pending[i] : void 0);
    }
    return _results;
  }
};

==> racer-0.1.3.tgz: package/lib/Serializer.js <==
var DEFAULT_TIMEOUT, Serializer, transaction;

transaction = require('./transaction');

DEFAULT_TIMEOUT = 1000;

module.exports = Serializer = function(_arg) {
  var init, onTimeout, self, timeout;
  this.withEach = _arg.withEach, onTimeout = _arg.onTimeout, timeout = _arg.timeout, init = _arg.init;
  self = this;
  if (onTimeout) {
    if (timeout === void 0) timeout = DEFAULT_TIMEOUT;
    self._setWaiter = function() {
      if (this._waiter) return;
      return this._waiter = setTimeout(function() {
        onTimeout();
        return self._clearWaiter();
      }, timeout);
    };
    self._clearWaiter = function() {
      if (this._waiter) {
        clearTimeout(this._waiter);
        return this._waiter = null;
      }
    };
  }
  self._pending = {};
  self._index = init != null ? init : 1;
};

Serializer.prototype = {
  _setWaiter: function() {},
  _clearWaiter: function() {},
  add: function(txn, txnIndex) {
    var index, pending;
    index = this._index;
    if (txnIndex > index) {
      this._pending[txnIndex] = txn;
      this._setWaiter();
      return true;
    }
    if (txnIndex < index) return false;
    this.withEach(txn, index);
    this._clearWaiter();
    index++;
    pending = this._pending;
    while (txn = pending[index]) {
      this.withEach(txn, index);
      delete pending[index++];
    }
    this._index = index;
    return true;
  },
  setIndex: function(_index) {
    this._index = _index;
  },
  clearPending: function() {
    var i, index, pending, _results;
    index = this._index;
    pending = this._pending;
    _results = [];
    for (i in pending) {
      if (i < index) {
        _results.push(delete pending[i]);
      } else {
        _results.push(void 0);
      }
    }
    return _results;
  }
};
